@@ -26,7 +26,7 @@ empty_zone_search_init(empty_zone_search_t *iter, dns_name_t *qname,
 
 isc_result_t
 empty_zone_handle_conflicts(dns_name_t *name, dns_zt_t *zonetable,
-			    isc_boolean_t warn_only) ATTR_NONNULLS ATTR_CHECKRESULT;
+			    bool warn_only) ATTR_NONNULLS ATTR_CHECKRESULT;
 
 /* Trigger to execute empty_zone_handle_conflicts() for dns_rootname. */
 #define LDAPDB_EVENT_GLOBALFWD_HANDLEEZ	(LDAPDB_EVENTCLASS + 5)
@@ -34,7 +34,7 @@ empty_zone_handle_conflicts(dns_name_t *name, dns_zt_t *zonetable,
 typedef struct ldap_globalfwd_handleez ldap_globalfwd_handleez_t;
 struct ldap_globalfwd_handleez {
 	ISC_EVENT_COMMON(ldap_globalfwd_handleez_t);
-	isc_boolean_t warn_only;
+	bool warn_only;
 };
 
 void
