@@ -3,6 +3,7 @@
  */
 
 #include <isc/rwlock.h>
+#include <isc/util.h>
 #include <dns/name.h>
 
 #include "rbt_helper.h"
@@ -100,7 +101,7 @@ fwdr_del_zone(fwd_register_t *fwdr, dns_name_t *name)
 
 	RWLOCK(&fwdr->rwlock, isc_rwlocktype_write);
 
-	CHECK(dns_rbt_deletename(fwdr->rbt, name, ISC_FALSE));
+	CHECK(dns_rbt_deletename(fwdr->rbt, name, false));
 
 cleanup:
 	RWUNLOCK(&fwdr->rwlock, isc_rwlocktype_write);
