@@ -5,7 +5,6 @@
 #include <isc/mem.h>
 #include <isc/rwlock.h>
 #include <isc/util.h>
-#include <isc/md5.h>
 #include <isc/string.h>
 
 #include <dns/db.h>
@@ -163,7 +162,7 @@ zr_destroy(zone_register_t **zrp)
 		if (result == ISC_R_SUCCESS) {
 			rbt_iter_stop(&iter);
 			result = ldap_delete_zone2(zr->ldap_inst,
-						   &name, ISC_FALSE);
+						   &name, false);
 			RUNTIME_CHECK(result == ISC_R_SUCCESS);
 		}
 	} while (result == ISC_R_SUCCESS);
@@ -221,7 +220,7 @@ zr_get_zone_path(isc_mem_t *mctx, settings_set_t *settings,
 
 	isc_buffer_init(&name_buf, name_char, sizeof(name_char));
 	CHECK(str_new(mctx, &zone_path));
-	CHECK(dns_name_tofilenametext(zone_name, ISC_TRUE, &name_buf));
+	CHECK(dns_name_tofilenametext(zone_name, true, &name_buf));
 	INSIST(isc_buffer_usedlength(&name_buf) > 0);
 
 	/* Root zone is special case: replace '.' with '@'
@@ -260,15 +259,15 @@ cleanup:
 static isc_result_t ATTR_NONNULL(1,2,4,5,6,8)
 create_zone_info(isc_mem_t * const mctx, dns_zone_t * const raw,
 		dns_zone_t * const secure, const char * const dn,
-		 settings_set_t *global_settings, const char *db_name,
+		 settings_set_t *global_settings, ldap_instance_t *inst,
 		 dns_db_t * const ldapdb, zone_info_t **zinfop)
 {
 	isc_result_t result;
 	zone_info_t *zinfo;
 	char settings_name[PRINT_BUFF_SIZE];
 	ld_string_t *zone_dir = NULL;
-	char *argv[1];
 
+	REQUIRE(inst != NULL);
 	REQUIRE(raw != NULL);
 	REQUIRE(dn != NULL);
 	REQUIRE(zinfop != NULL && *zinfop == NULL);
@@ -294,11 +293,9 @@ create_zone_info(isc_mem_t * const mctx, dns_zone_t * const raw,
 	CHECK(fs_dirs_create(str_buf(zone_dir)));
 
 	if (ldapdb == NULL) { /* create new empty database */
-		DE_CONST(db_name, argv[0]);
 		CHECK(ldapdb_create(mctx, dns_zone_getorigin(raw),
 				    LDAP_DB_TYPE, LDAP_DB_RDATACLASS,
-				    sizeof(argv)/sizeof(argv[0]),
-				    argv, NULL, &zinfo->ldapdb));
+				    inst, &zinfo->ldapdb));
 	} else { /* re-use existing database */
 		dns_db_attach(ldapdb, &zinfo->ldapdb);
 	}
@@ -396,8 +393,7 @@ zr_add_zone(zone_register_t * const zr, dns_db_t * const ldapdb,
 	}
 
 	CHECK(create_zone_info(zr->mctx, raw, secure, dn, zr->global_settings,
-			       ldap_instance_getdbname(zr->ldap_inst), ldapdb,
-			       &new_zinfo));
+			       zr->ldap_inst, ldapdb, &new_zinfo));
 	CHECK(dns_rbt_addname(zr->rbt, name, new_zinfo));
 
 cleanup:
@@ -421,7 +417,7 @@ zr_del_zone(zone_register_t *zr, dns_name_t *origin)
 
 	RWLOCK(&zr->rwlock, isc_rwlocktype_write);
 
-	CHECK(dns_rbt_deletename(zr->rbt, origin, ISC_FALSE));
+	CHECK(dns_rbt_deletename(zr->rbt, origin, false));
 
 cleanup:
 	RWUNLOCK(&zr->rwlock, isc_rwlocktype_write);
@@ -604,21 +600,21 @@ delete_bind_zone(dns_zt_t *zt, dns_zone_t **zonep) {
 }
 
 /* Test if the existing zone is 'empty zone' per RFC 6303. */
-isc_boolean_t ATTR_NONNULLS ATTR_CHECKRESULT
+bool ATTR_NONNULLS ATTR_CHECKRESULT
 zone_isempty(dns_zone_t *zone) {
 	char **argv = NULL;
 	isc_mem_t *mctx = NULL;
-	isc_boolean_t result = ISC_FALSE;
+	bool result = false;
 
 	mctx = dns_zone_getmctx(zone);
 	if (dns_zone_getdbtype(zone, &argv, mctx) != ISC_R_SUCCESS)
-		CLEANUP_WITH(ISC_FALSE);
+		CLEANUP_WITH(false);
 
 	if (argv[0] != NULL && strcmp("_builtin", argv[0]) == 0 &&
 	    argv[1] != NULL && strcmp("empty", argv[1]) == 0) {
-		result = ISC_TRUE;
+		result = true;
 	} else {
-		result = ISC_FALSE;
+		result = false;
 	}
 	isc_mem_free(mctx, argv);
 
